==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/mixin/ItemStackMixin.java <==
package com.zurrtum.create.mixin;

import com.llamalad7.mixinextras.sugar.Local;
import com.llamalad7.mixinextras.sugar.Share;
import com.llamalad7.mixinextras.sugar.ref.LocalRef;
import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.content.contraptions.glue.SuperGlueHandler;
import com.zurrtum.create.content.equipment.symmetryWand.SymmetryHandler;
import com.zurrtum.create.infrastructure.component.ClipboardContent;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1935;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_9331;
import net.minecraft.class_9334;
import net.minecraft.class_9335;
import net.minecraft.item.*;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.function.BiFunction;

@Mixin(class_1799.class)
public class ItemStackMixin {
    @Inject(method = "useOnBlock(Lnet/minecraft/item/ItemUsageContext;)Lnet/minecraft/util/ActionResult;", at = @At(value = "INVOKE", target = "Lnet/minecraft/item/Item;useOnBlock(Lnet/minecraft/item/ItemUsageContext;)Lnet/minecraft/util/ActionResult;"))
    private void cacheState(
        class_1838 context,
        CallbackInfoReturnable<class_1269> cir,
        @Local class_1792 item,
        @Share("place") LocalRef<class_1750> place
    ) {
        if (item instanceof class_1747) {
            class_1937 world = context.method_8045();
            if (!world.method_8608()) {
                place.set(new class_1750(context));
            }
        }
    }

    @Inject(method = "useOnBlock(Lnet/minecraft/item/ItemUsageContext;)Lnet/minecraft/util/ActionResult;", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/ActionResult$Success;shouldIncrementStat()Z"))
    private void useOnBlock(
        class_1838 context,
        CallbackInfoReturnable<class_1269> cir,
        @Local class_1657 player,
        @Share("place") LocalRef<class_1750> place
    ) {
        class_1750 placementContext = place.get();
        if (placementContext != null) {
            class_3218 world = (class_3218) context.method_8045();
            class_2338 pos = placementContext.method_8037();
            SuperGlueHandler.glueListensForBlockPlacement(world, player, pos);
            if (!context.method_8041().field_49270.method_57832(class_9334.field_53964)) {
                SymmetryHandler.onBlockPlaced(world, player, pos, placementContext);
            }
        }
    }

    @SuppressWarnings("removal")
    @Inject(method = "<init>(Lnet/minecraft/item/ItemConvertible;ILnet/minecraft/component/MergedComponentMap;)V", at = @At("TAIL"))
    private void create$migrateOldClipboardComponents(class_1935 item, int count, class_9335 components, CallbackInfo ci) {
        ClipboardContent content = ClipboardContent.EMPTY;

        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_PAGES, ClipboardContent::setPages);
        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_TYPE, ClipboardContent::setType);
        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_READ_ONLY, (c, v) -> c.setReadOnly(true));
        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_COPIED_VALUES, ClipboardContent::setCopiedValues);
        content = create$migrateComponent(
            content,
            components,
            AllDataComponents.CLIPBOARD_PREVIOUSLY_OPENED_PAGE,
            ClipboardContent::setPreviouslyOpenedPage
        );

        if (content != ClipboardContent.EMPTY) {
            components.method_57938(AllDataComponents.CLIPBOARD_CONTENT, content);
        }
    }

    @Unique
    private static <T> ClipboardContent create$migrateComponent(
        ClipboardContent content,
        class_9335 components,
        class_9331<T> componentType,
        BiFunction<ClipboardContent, T, ClipboardContent> function
    ) {
        T value = components.method_58694(componentType);
        if (value != null) {
            components.method_57939(componentType);
            content = function.apply(content, value);
        }

        return content;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/mixin/ItemStackMixin.java <==
package com.zurrtum.create.mixin;

import com.llamalad7.mixinextras.sugar.Local;
import com.llamalad7.mixinextras.sugar.Share;
import com.llamalad7.mixinextras.sugar.ref.LocalRef;
import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.content.contraptions.glue.SuperGlueHandler;
import com.zurrtum.create.content.equipment.symmetryWand.SymmetryHandler;
import com.zurrtum.create.infrastructure.component.ClipboardContent;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.function.BiFunction;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1935;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_9331;
import net.minecraft.class_9334;
import net.minecraft.class_9335;

@Mixin(class_1799.class)
public class ItemStackMixin {
    @Inject(method = "useOn(Lnet/minecraft/world/item/context/UseOnContext;)Lnet/minecraft/world/InteractionResult;", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/Item;useOn(Lnet/minecraft/world/item/context/UseOnContext;)Lnet/minecraft/world/InteractionResult;"))
    private void cacheState(
        class_1838 context,
        CallbackInfoReturnable<class_1269> cir,
        @Local class_1792 item,
        @Share("place") LocalRef<class_1750> place
    ) {
        if (item instanceof class_1747) {
            class_1937 world = context.method_8045();
            if (!world.method_8608()) {
                place.set(new class_1750(context));
            }
        }
    }

    @Inject(method = "useOn(Lnet/minecraft/world/item/context/UseOnContext;)Lnet/minecraft/world/InteractionResult;", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/InteractionResult$Success;wasItemInteraction()Z"))
    private void useOnBlock(
        class_1838 context,
        CallbackInfoReturnable<class_1269> cir,
        @Local class_1657 player,
        @Share("place") LocalRef<class_1750> place
    ) {
        class_1750 placementContext = place.get();
        if (placementContext != null) {
            class_3218 world = (class_3218) context.method_8045();
            class_2338 pos = placementContext.method_8037();
            SuperGlueHandler.glueListensForBlockPlacement(world, player, pos);
            if (!context.method_8041().field_49270.method_57832(class_9334.field_53964)) {
                SymmetryHandler.onBlockPlaced(world, player, pos, placementContext);
            }
        }
    }

    @SuppressWarnings("removal")
    @Inject(method = "<init>(Lnet/minecraft/world/level/ItemLike;ILnet/minecraft/core/component/PatchedDataComponentMap;)V", at = @At("TAIL"))
    private void create$migrateOldClipboardComponents(class_1935 item, int count, class_9335 components, CallbackInfo ci) {
        ClipboardContent content = ClipboardContent.EMPTY;

        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_PAGES, ClipboardContent::setPages);
        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_TYPE, ClipboardContent::setType);
        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_READ_ONLY, (c, v) -> c.setReadOnly(true));
        content = create$migrateComponent(content, components, AllDataComponents.CLIPBOARD_COPIED_VALUES, ClipboardContent::setCopiedValues);
        content = create$migrateComponent(
            content,
            components,
            AllDataComponents.CLIPBOARD_PREVIOUSLY_OPENED_PAGE,
            ClipboardContent::setPreviouslyOpenedPage
        );

        if (content != ClipboardContent.EMPTY) {
            components.method_57938(AllDataComponents.CLIPBOARD_CONTENT, content);
        }
    }

    @Unique
    private static <T> ClipboardContent create$migrateComponent(
        ClipboardContent content,
        class_9335 components,
        class_9331<T> componentType,
        BiFunction<ClipboardContent, T, ClipboardContent> function
    ) {
        T value = components.method_58694(componentType);
        if (value != null) {
            components.method_57939(componentType);
            content = function.apply(content, value);
        }

        return content;
    }
}
